@@ -70,7 +70,8 @@
 #' + only `AxxDTM` then `ASTDTM`,`AENDTM` are computed
 #' + only `AxxDT` then `ASTDT`,`AENDT` are computed.
 #'
-#' @keywords derivation bds adex
+#' @family der_prm_bds_findings
+#' @keywords der_prm_bds_findings
 #'
 #' @export
 #'
@@ -161,31 +162,32 @@ derive_param_exposure <- function(dataset,
     filter_if(filter)
 
   add_data <- subset_ds %>%
-    filter(PARAMCD == input_code) %>%
-    derive_summary_records(
+    get_summary_records(
       by_vars = by_vars,
+      filter = PARAMCD == input_code,
       analysis_var = !!analysis_var,
       summary_fun = summary_fun,
       set_values_to = set_values_to
-    ) %>%
-    filter(PARAMCD == quo_get_expr(set_values_to$PARAMCD))
+    )
 
   # add the dates for the derived parameters
+  tmp_start <- get_new_tmp_var(dataset)
+  tmp_end <- get_new_tmp_var(dataset)
   if (all(dtm)) {
     dates <- subset_ds %>%
       group_by(!!!by_vars) %>%
       summarise(
-        temp_start = min(ASTDTM, na.rm = TRUE),
-        temp_end = max(coalesce(AENDTM, ASTDTM), na.rm = TRUE)
+        !!tmp_start := min(ASTDTM, na.rm = TRUE),
+        !!tmp_end := max(coalesce(AENDTM, ASTDTM), na.rm = TRUE)
       ) %>%
       ungroup()
     expo_data <- add_data %>%
       derive_vars_merged(dataset_add = dates, by_vars = by_vars) %>%
       mutate(
-        ASTDTM = coalesce(ASTDTM, temp_start),
-        AENDTM = coalesce(AENDTM, temp_end)
+        ASTDTM = !!tmp_start,
+        AENDTM = !!tmp_end
       ) %>%
-      select(-starts_with("temp_"))
+      remove_tmp_vars()
 
     if (all(dt)) {
       expo_data <- expo_data %>%
@@ -195,25 +197,18 @@ derive_param_exposure <- function(dataset,
     dates <- subset_ds %>%
       group_by(!!!by_vars) %>%
       summarise(
-        temp_start = min(ASTDT, na.rm = TRUE),
-        temp_end = max(coalesce(AENDT, ASTDT), na.rm = TRUE)
+        !!tmp_start := min(ASTDT, na.rm = TRUE),
+        !!tmp_end := max(coalesce(AENDT, ASTDT), na.rm = TRUE)
       ) %>%
       ungroup()
     expo_data <- add_data %>%
       derive_vars_merged(dataset_add = dates, by_vars = by_vars) %>%
       mutate(
-        ASTDT = coalesce(ASTDT, temp_start),
-        AENDT = coalesce(AENDT, temp_end)
+        ASTDT = !!tmp_start,
+        AENDT = !!tmp_end
       ) %>%
-      select(-starts_with("temp_"))
+      remove_tmp_vars()
   }
 
-  all_data <- bind_rows(dataset, expo_data)
-
-  if (all(dtm)) {
-    attr(all_data$ASTDTM, "tzone") <- "UTC"
-    attr(all_data$AENDTM, "tzone") <- "UTC"
-  }
-
-  all_data
+  bind_rows(dataset, expo_data)
 }
