@@ -73,9 +73,7 @@
 #'
 #'   \item The `ADT` variable is set to the variable specified by the
 #'   \code{date} element. If the date variable is a datetime variable, only
-#'   the datepart is copied. If the source variable is a character variable, it
-#'   is converted to a date. If the date is incomplete, it is imputed as the
-#'   first possible date.
+#'   the datepart is copied.
 #'
 #'   \item The `CNSR` variable is added and set to the \code{censor} element.
 #'
@@ -96,9 +94,7 @@
 #'
 #'   \item The `ADT` variable is set to the variable specified by the
 #'   \code{date} element. If the date variable is a datetime variable, only
-#'   the datepart is copied. If the source variable is a character variable, it
-#'   is converted to a date. If the date is incomplete, it is imputed as the
-#'   first possible date.
+#'   the datepart is copied.
 #'
 #'   \item The `CNSR` variable is added and set to the \code{censor} element.
 #'
@@ -127,11 +123,13 @@
 #'
 #' @return The input dataset with the new parameter added
 #'
-#' @keywords derivation bds
+#' @family der_prm_tte
+#' @keywords der_prm_tte
 #'
 #' @export
 #'
 #' @examples
+#' library(tibble)
 #' library(dplyr, warn.conflicts = FALSE)
 #' library(lubridate)
 #' data("admiral_adsl")
@@ -173,14 +171,14 @@
 #'   filter(row_number() %in% 20:30)
 #'
 #' # derive time to adverse event for each preferred term #
-#' adsl <- tibble::tribble(
+#' adsl <- tribble(
 #'   ~USUBJID, ~TRTSDT,           ~EOSDT,
 #'   "01",     ymd("2020-12-06"), ymd("2021-03-06"),
 #'   "02",     ymd("2021-01-16"), ymd("2021-02-03")
 #' ) %>%
 #'   mutate(STUDYID = "AB42")
 #'
-#' ae <- tibble::tribble(
+#' ae <- tribble(
 #'   ~USUBJID, ~AESTDTC,           ~AESEQ, ~AEDECOD,
 #'   "01",     "2021-01-03T10:56", 1,      "Flu",
 #'   "01",     "2021-03-04",       2,      "Cough",
@@ -188,9 +186,17 @@
 #' ) %>%
 #'   mutate(STUDYID = "AB42")
 #'
+#' ae_ext <- derive_vars_dt(
+#'   ae,
+#'   dtc = AESTDTC,
+#'   new_vars_prefix = "AEST",
+#'   highest_imputation = "M",
+#'   flag_imputation = "none"
+#' )
+#'
 #' ttae <- event_source(
 #'   dataset_name = "ae",
-#'   date = AESTDTC,
+#'   date = AESTDT,
 #'   set_values_to = vars(
 #'     EVNTDESC = "AE",
 #'     SRCDOM = "AE",
@@ -215,7 +221,7 @@
 #'   start_date = TRTSDT,
 #'   event_conditions = list(ttae),
 #'   censor_conditions = list(eos),
-#'   source_datasets = list(adsl = adsl, ae = ae),
+#'   source_datasets = list(adsl = adsl, ae = ae_ext),
 #'   set_values_to = vars(
 #'     PARAMCD = paste0("TTAE", as.numeric(as.factor(AEDECOD))),
 #'     PARAM = paste("Time to First", AEDECOD, "Adverse Event"),
@@ -280,6 +286,7 @@ derive_param_tte <- function(dataset = NULL,
     )
   }
 
+  tmp_event <- get_new_tmp_var(dataset)
   # determine events #
   event_data <- filter_date_sources(
     sources = event_conditions,
@@ -289,7 +296,7 @@ derive_param_tte <- function(dataset = NULL,
     subject_keys = subject_keys,
     mode = "first"
   ) %>%
-    mutate(temp_event = 1)
+    mutate(!!tmp_event := 1L)
 
   # determine censoring observations #
   censor_data <- filter_date_sources(
@@ -300,7 +307,7 @@ derive_param_tte <- function(dataset = NULL,
     subject_keys = subject_keys,
     mode = "last"
   ) %>%
-    mutate(temp_event = 0)
+    mutate(!!tmp_event := 0L)
 
   # determine variable to add from ADSL #
   if (create_datetime) {
@@ -340,7 +347,7 @@ derive_param_tte <- function(dataset = NULL,
   new_param <- filter_extreme(
     bind_rows(event_data, censor_data),
     by_vars = quo_c(subject_keys, by_vars),
-    order = vars(temp_event),
+    order = vars(!!tmp_event),
     mode = "last"
   ) %>%
     derive_vars_merged(
@@ -370,7 +377,7 @@ derive_param_tte <- function(dataset = NULL,
 
   new_param <- new_param %>%
     mutate(!!date_var := pmax(!!date_var, !!start_var)) %>%
-    select(-starts_with("temp_"))
+    remove_tmp_vars()
 
   if (!is.null(by_vars)) {
     if (!is.null(set_values_to$PARAMCD)) {
@@ -447,30 +454,37 @@ derive_param_tte <- function(dataset = NULL,
 #'
 #' @author Stefan Bundfuss
 #'
-#' @keywords dev_utility
+#' @keywords source_specifications
+#' @family source_specifications
+#'
+#' @export
 #'
 #' @examples
+#' library(tibble)
 #' library(dplyr, warn.conflicts = FALSE)
 #' library(lubridate)
 #'
-#' adsl <- tibble::tribble(
+#' adsl <- tribble(
 #'   ~USUBJID, ~TRTSDT,           ~EOSDT,
 #'   "01",     ymd("2020-12-06"), ymd("2021-03-06"),
 #'   "02",     ymd("2021-01-16"), ymd("2021-02-03")
 #' ) %>%
 #'   mutate(STUDYID = "AB42")
 #'
-#' ae <- tibble::tribble(
-#'   ~USUBJID, ~AESTDTC,           ~AESEQ, ~AEDECOD,
-#'   "01",     "2021-01-03T10:56", 1,      "Flu",
-#'   "01",     "2021-03-04",       2,      "Cough",
-#'   "01",     "2021",             3,      "Flu"
+#' ae <- tribble(
+#'   ~USUBJID, ~AESTDTC,     ~AESEQ, ~AEDECOD,
+#'   "01",     "2021-01-03", 1,      "Flu",
+#'   "01",     "2021-03-04", 2,      "Cough",
+#'   "01",     "2021-01-01", 3,      "Flu"
 #' ) %>%
-#'   mutate(STUDYID = "AB42")
+#'   mutate(
+#'     STUDYID = "AB42",
+#'     AESTDT = ymd(AESTDTC)
+#'   )
 #'
 #' ttae <- event_source(
 #'   dataset_name = "ae",
-#'   date = AESTDTC,
+#'   date = AESTDT,
 #'   set_values_to = vars(
 #'     EVNTDESC = "AE",
 #'     SRCDOM = "AE",
@@ -487,7 +501,6 @@ derive_param_tte <- function(dataset = NULL,
 #'   subject_keys = vars(STUDYID, USUBJID),
 #'   mode = "first"
 #' )
-#' @export
 filter_date_sources <- function(sources,
                                 source_datasets,
                                 by_vars,
@@ -513,7 +526,13 @@ filter_date_sources <- function(sources,
   data <- vector("list", length(sources))
   for (i in seq_along(sources)) {
     date <- sources[[i]]$date
-    data[[i]] <- source_datasets[[sources[[i]]$dataset_name]] %>%
+    source_dataset <- source_datasets[[sources[[i]]$dataset_name]]
+    assert_date_var(
+      dataset = source_dataset,
+      var = !!date,
+      dataset_name = sources[[i]]$dataset_name
+    )
+    data[[i]] <- source_dataset %>%
       filter_if(sources[[i]]$filter) %>%
       filter_extreme(
         order = vars(!!date),
@@ -521,30 +540,12 @@ filter_date_sources <- function(sources,
         mode = mode,
         check_type = "none"
       )
+
     # add date variable and accompanying variables
-    if (is.instant(pull(data[[i]], !!date))) {
-      if (create_datetime) {
-        date_derv <- vars(!!date_var := as_datetime(!!date))
-      } else {
-        date_derv <- vars(!!date_var := date(!!date))
-      }
+    if (create_datetime) {
+      date_derv <- vars(!!date_var := as_datetime(!!date))
     } else {
-      if (create_datetime) {
-        date_derv <- vars(
-          !!date_var := convert_dtc_to_dtm(
-            !!date,
-            date_imputation = "first",
-            time_imputation = "first"
-          )
-        )
-      } else {
-        date_derv <- vars(
-          !!date_var := convert_dtc_to_dt(
-            !!date,
-            date_imputation = "first"
-          )
-        )
-      }
+      date_derv <- vars(!!date_var := date(!!date))
     }
 
     data[[i]] <- transmute(
@@ -593,7 +594,8 @@ filter_date_sources <- function(sources,
 #'
 #' @author Stefan Bundfuss
 #'
-#' @keywords dev_utility
+#' @keywords source_specifications
+#' @family source_specifications
 #'
 #' @examples
 #' library(dplyr, warn.conflicts = FALSE)
@@ -689,8 +691,7 @@ extend_source_datasets <- function(source_datasets,
 #'   `dataset` which are events or possible censoring time points.
 #'
 #' @param date A variable providing the date of the event or censoring. A date,
-#'   a datetime, or a character variable containing ISO 8601 dates can be
-#'   specified. An unquoted symbol is expected.
+#'   or a datetime can be specified. An unquoted symbol is expected.
 #'
 #'   Refer to `derive_vars_dt()` to impute and derive a date from a date
 #'   character vector to a date object.
@@ -707,7 +708,8 @@ extend_source_datasets <- function(source_datasets,
 #'
 #' @author Stefan Bundfuss
 #'
-#' @keywords dev_utility
+#' @keywords source_specifications
+#' @family source_specifications
 #'
 #' @seealso [derive_param_tte()], [censor_source()], [event_source()]
 #'
@@ -740,6 +742,7 @@ tte_source <- function(dataset_name,
 #'
 #' @author Stefan Bundfuss
 #'
+#' @family source_specifications
 #' @keywords source_specifications
 #'
 #' @seealso [derive_param_tte()], [censor_source()]
@@ -784,6 +787,7 @@ event_source <- function(dataset_name,
 #'
 #' @author Stefan Bundfuss
 #'
+#' @family source_specifications
 #' @keywords source_specifications
 #'
 #' @seealso [derive_param_tte()], [event_source()]
@@ -826,6 +830,11 @@ censor_source <- function(dataset_name,
 #'
 #' @return No return value, called for side effects
 #'
+#' @author Thomas Neitmann
+#'
+#' @keywords internal
+#' @family internal
+#'
 #' @export
 #'
 #' @seealso [tte_source()], [censor_source()], [event_source()]
@@ -845,16 +854,44 @@ print.tte_source <- function(x, ...) {
   }
 }
 
-list_tte_source_objects <- function() {
-  # Get all tte_source objects exported by admiral
-  exported <- getNamespaceExports("admiral")
-  objects <-
-    exported[map_lgl(exported, function(obj_name) {
-      inherits(get(obj_name), "tte_source")
-    })]
 
-  rows <- lapply(objects, function(obj_name) {
-    obj <- get(obj_name)
+#' List all `tte_source` Objects Available in a Package
+#'
+#' @param package The name of the package in which to search for `tte_source` objects
+#'
+#' @return
+#' A `data.frame` where each row corresponds to one `tte_source` object or `NULL`
+#' if `package` does not contain any `tte_source` objects
+#'
+#' @author Thomas Neitmann
+#'
+#' @export
+#'
+#' @family source_specifications
+#' @keywords source_specifications
+#'
+#' @examples
+#' list_tte_source_objects()
+list_tte_source_objects <- function(package = "admiral") {
+  assert_character_scalar(package)
+
+  if (!requireNamespace(package, quietly = TRUE)) {
+    err_msg <- sprintf(
+      "No package called '%s' is installed and hence no `tte_source` objects are available",
+      package
+    )
+    abort(err_msg)
+  }
+
+  # Get all `tte_source` objects exported by `package`
+  exports <- getNamespaceExports(package)
+  is_tte_source <- map_lgl(exports, function(obj_name) {
+    inherits(getExportedValue(package, obj_name), "tte_source")
+  })
+  tte_sources <- exports[is_tte_source]
+
+  rows <- lapply(tte_sources, function(obj_name) {
+    obj <- getExportedValue(package, obj_name)
     data.frame(
       object = obj_name,
       dataset_name = obj$dataset_name,
