@@ -2,6 +2,7 @@
 #'
 #' @param adam_name An ADaM dataset name. You can use any of the available dataset name `r list_all_templates()`, and the dataset name is case-insensitive. The default dataset name is ADSL.
 #' @param save_path Path to save the script.
+#' @param package The R package in which to look for templates. By default `"admiral"`.
 #' @param overwrite Whether to overwrite an existing file named `save_path`.
 #' @param open Whether to open the script right away.
 #'
@@ -11,7 +12,8 @@
 #'
 #' @author Shimeng Huang, Thomas Neitmann
 #'
-#' @keywords user_utility
+#' @family utils_examples
+#' @keywords utils_examples
 #'
 #' @export
 #'
@@ -21,17 +23,22 @@
 #' }
 use_ad_template <- function(adam_name = "adsl",
                             save_path = paste0("./", adam_name, ".R"),
+                            package = "admiral",
                             overwrite = FALSE,
                             open = interactive()) {
   assert_character_scalar(adam_name)
   assert_character_scalar(save_path)
+  assert_character_scalar(package)
   assert_logical_scalar(overwrite)
   assert_logical_scalar(open)
 
-  if (!toupper(adam_name) %in% list_all_templates()) {
-    err_msg <- paste0(
-      sprintf("No template for '%s' available.\n", toupper(adam_name)),
-      "\u2139 Run `list_all_templates()` to get a list of all available ADaM templates."
+  if (!toupper(adam_name) %in% list_all_templates(package)) {
+    err_msg <- sprintf(
+      paste0(
+        "No template for '%s' available in package '%s'.\n",
+        "\u2139 Run `list_all_templates('%s')` to get a list of all available ADaM templates."
+      ),
+      toupper(adam_name), package, package
     )
     abort(err_msg)
   }
@@ -47,7 +54,7 @@ use_ad_template <- function(adam_name = "adsl",
 
   template_file <- system.file(
     paste0("templates/ad_", tolower(adam_name), ".R"),
-    package = "admiral"
+    package = package
   )
 
   if (file.copy(template_file, save_path, overwrite = TRUE)) {
@@ -63,9 +70,12 @@ use_ad_template <- function(adam_name = "adsl",
 
 #' List All Available ADaM Templates
 #'
+#' @param package The R package in which to look for templates. By default `"admiral"`.
+#'
 #' @author Shimeng Huang, Thomas Neitmann
 #'
-#' @keywords user_utility
+#' @family utils_examples
+#' @keywords utils_examples
 #'
 #' @return A `character` vector of all available templates
 #'
@@ -73,15 +83,46 @@ use_ad_template <- function(adam_name = "adsl",
 #'
 #' @examples
 #' list_all_templates()
-list_all_templates <- function() {
-  list.files(system.file("templates", package = "admiral")) %>%
+list_all_templates <- function(package = "admiral") {
+  assert_character_scalar(package)
+
+  if (!requireNamespace(package, quietly = TRUE)) {
+    err_msg <- sprintf("No package called '%s' is installed and hence no templates are available", package)
+    abort(err_msg)
+  }
+
+  list.files(system.file("templates", package = package)) %>%
     str_remove(".R$") %>%
     str_remove("^ad_") %>%
     toupper() %>%
-    structure(class = c("adam_templates", "character"))
+    structure(class = c("adam_templates", "character"), package = package)
 }
 
+#' Print `adam_templates` Objects
+#'
+#' @param x A `adam_templates` object
+#' @param ... Not used
+#'
+#' @return No return value, called for side effects
+#'
+#' @author Thomas Neitmann
+#'
+#' @export
+#'
+#' @keywords internal
+#' @family internal
+#'
+#' @seealso [list_all_templates()]
+#'
+#' @examples
+#' templates <- list_all_templates()
+#' print(templates)
 print.adam_templates <- function(x, ...) {
-  cat("Existing templates:\n")
-  cat(paste0("\U2022 ", x), sep = "\n")
+  pkg <- attr(x, "package")
+  if (length(x) == 0L) {
+    cat("No ADaM templates available in package '", pkg, "'\n", sep = "")
+  } else {
+    cat("Existing ADaM templates in package '", pkg, "':\n", sep = "")
+    cat(paste0("\U2022 ", x), sep = "\n")
+  }
 }
